function demo3DDynamic()
% demo3DDynamic
%
% Learns a random walk from time series images as in Figure 6 and 7 of
% Johnson 2015
%
% What you need
% -------------
% * a valid CellOrganizer diffeomorphic model
%
% Output
% ------
% * a viz of the shape space

% Gregory Johnson
%
% Copyright (C) 2012-2016 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DO NOT MODIFY THIS BLOCK
answer = false;
current_path = which(mfilename);
[current_path, filename, extension] = fileparts( current_path );
cd(current_path);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

disclaimer = ['This demo requires a lot of resources to compute. ' ...
    'It might fail to run in a personal computer.'];
warning( disclaimer );

url = 'http://www.cellorganizer.org/Downloads/demos';
filename = 'demo3D_dynamic_data.zip';

if ~exist( filename )
    disp( ['Downloading ' filename ' to run this demo.']);
    try
        websave( filename, [url '/' filename ]);
    catch
        urlwrite([url '/' filename ], filename);
    end
else
    disp( ['File ' filename ' found. Skipping download.']);
end

disp( 'Attempting to extract data' );
try
    unzip( filename )
catch err
    getReport( err )
    warning('Unable to extract data. Exiting demo.');
    return
end

disp( 'Loading data. This might take a few minutes.' )
try
    load( 'cellModel_nuc_align.mat' )
    load( 'dna_intens.mat' )
    load( 'object_info_v3.mat' );
    parentdir = pwd;
catch err
    getReport( err )
    warning( 'Unable to load data. Exiting demo.' )
end

script_kde_trans_model_alon(model, 'Johnson_2015', object_info, parentdir)
