function answer = demo3D22()
% demo3D22
%
% Synthesizes a protein pattern instance from the synthetic image produced
% in demo3DDiffeoSynth.
%
% What you need
% -------------
% * a synthetic framework
%
% Output
% ------
% * a synthetic image

% Created: Devin Sullivan
%
% Copyright (C) 2014-2016 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DO NOT MODIFY THIS BLOCK
answer = true;
current_path = which(mfilename);
[current_path, filename, extension] = fileparts( current_path );
cd(current_path);

options.seed = 12345;
try
    state = rng( options.seed );
catch err
    state = rand( 'seed', options.seed ); %#ok<RAND>
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

try
    pattern = '../demo3D30/demo3DDiffeoSynth_uniform.m_img1';
    copyfile( pattern );
catch err
    warning('Unable to copy files. Exiting demo');
    getReport(err)
    return
end

folder = './demo3DDiffeoSynth_uniform.m_img1';
answer = answer && helper_function( folder );
end

function answer = helper_function( folder )
outputDirectory = pwd;
options = [];
options.targetDirectory = folder;
options.prefix = 'synthesizedImages';
options.numberOfSynthesizedImages = 1;
options.compression = 'lzw';
options.microscope = 'none';
options.sampling.method = 'disc';
options.verbose = true;
options.debug = true;
options.synthesis = 'all';

%make sure objects don't overlap.
options.rendAtStd = 1;
options.objstd = 1.1;
options.overlapsubsize = 1;
options.output.tifimages = 1;
%output the SBML-spatial files
options.output.SBML = 1;

options.model.resolution = [0.3920,0.3920,0.4000];
options.resolution.cell = [0.3920,0.3920,0.4000];
load( [ folder filesep 'temp' filesep 'image1.mat' ] );
options.instance.nucleus = img;
options.instance.resolution= [0.3920,0.3920,0.4000];
clear img

load( [ folder filesep 'temp' filesep 'image2.mat' ] );
options.instance.cell = img;
clear img

%trim image
img2d = squeeze(sum(options.instance.cell,3));
xrange = find(sum(img2d,1)>0);
yrange = find(sum(img2d,2)>0);
zrange = find(sum(sum(options.instance.cell,1),2));

options.instance.cell = options.instance.cell(min(yrange):max(yrange), ...
    min(xrange):max(xrange),min(zrange):max(zrange));
options.instance.nucleus = options.instance.nucleus(min(yrange):max(yrange), ...
    min(xrange):max(xrange),min(zrange):max(zrange));

answer = slml2img( {'../../../models/3D/tfr.mat'}, options );
end
