function answer = demo3D23()
% demo3D23
%
% Train 3D generative diffeomorphic nuclear and cell shape model and a
% lysosomal model from all LAMP2 images in the Murphy Lab 3D HeLa dataset.
%
% What you need
% -------------
% * a directory of raw or synthetic nucleus images
% * a directory of raw or synthetic cell shape images
% * a directory of raw or synthetic lysosome images
% * the resolution of the images (all images should have the same
%   resolution)
%
% Output
% ------
% * a valid SLML model file

% Created: Gregory Johnson
%
% Copyright (C) 2013-2016 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DO NOT MODIFY THIS BLOCK
current_path = which(mfilename);
[current_path, filename, extension] = fileparts( current_path );
cd(current_path);

%check if images are present. if not, then download;
get_murphylab_image_collections();
cd(current_path);

pattern = 'LAMP2';
param.protein.class = 'lysosome';
param.protein.name = 'lamp2';
param.nucleus.name = 'lamp2';
param.cell.model = 'lamp2';

directory = '../../../images/HeLa/3D/processed';
dna = [directory filesep 'LAM*cell*ch0*.tif'] ;
cell = [directory filesep 'LAM*cell*ch1*.tif'];
protein = [directory filesep 'LAM*cell*ch2*.tif'];
options.masks = [directory filesep 'LAM*cell*mask*.tif'];

dimensionality = '3D';

% param.masks = [directory filesep 'cell*mask*.tif'];

% generic model options
% ---------------------
% model.name                (optional) Holds the name of the model. Default is empty.
param.model.name = 'all';

% model.id                  (optional) Holds the id of the model. Default is empty.
param.model.id = num2str(now);

% model.filename            Holds the output filename.
param.model.filename = [ lower(pattern) '.xml' ];

% nucleus.id                (optional) Holds the id of the nuclear model. Default is empty.
param.nucleus.type = 'diffeomorphic';
param.nucleus.class = 'frameworl';
param.nucleus.id = num2str(now);


% cell shape model options
% ------------------------
% cell.type                 Holds the cell model type. Default is "ratio".
param.cell.type = 'diffeomorphic';
param.cell.class = 'framework';
param.cell.id = num2str(now);


% protein shape model options
% ---------------------------
% protein.type              (optional) Holds the protein model type. The default is "vesicle".
param.protein.type = 'gmm';
param.protein.class = 'vesicle';
param.protein.id = num2str(now);

% protein.cytonuclearflag   (optional) Determines whether the protein pattern will be generated in
%                           the cytosolic space ('cyto'), nuclear space ('nuc') or everywhere ('all').
%                           Default is cyto.
if strcmpi( param.protein.class, 'nuc' )
    param.protein.cytonuclearflag = 'nuc';
else
    param.protein.cytonuclearflag = 'cyto';
end

% other options
% -------------
% verbose                   (optional) Displays messages to screen. The default is true.
param.verbose = true;

% debug                     (optional) Reports errors and warnings. Default is false.
param.debug = true;

% train.flag                (optional) Selects what model is going to be trained ('nuclear',
%                           'framework', or 'all'). Default is 'all'
param.train.flag = 'all';

%documentation
param.documentation.description = 'This model has been trained using demo3D20_2D from CellOrganizer';

%model resolution
param.downsampling = [10,10,1];

%this is the resolution of the datasets
param.model.resolution = [0.049, 0.049, 0.2000];
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

answer = img2slml( dimensionality, dna, cell, protein, param );