function answer = demo3DDiffeoSynth_uniform()
% demo3DDiffeoSynth_uniform
% 
% This demo illustrates how to sample uniformly at random from a
% diffeomorphic model.
%
% What you need
% -------------
% * a valid CellOrganizer model file
%
% Output
% ------
% * a random walk

% Created: Devin Sullivan
%
% Copyright (C) 2012-2016 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DO NOT MODIFY THIS BLOCK
answer = false;
current_path = which(mfilename);
[current_path, filename, extension] = fileparts( current_path );
cd(current_path);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

param.targetDirectory = scriptname;

load('helamodel.mat')

cellinds = find(all(~isnan(model.cellShapeModel.positions),2));

positions = model.cellShapeModel.positions(cellinds,:);

minpos = min(positions,[],1);
maxpos = max(positions,[],1);

numimgs = 5;
for i = 1:numimgs %this may take a few seconds, and of course will take long the greater the dimensionality of the space
    %sample from the uniform distribution ANDed to the convex hull of the triangulation
    simplex_idx = nan;
    
    while isnan(simplex_idx)
        point = rand([1, size(minpos,2)]).*(maxpos - minpos) + minpos;
        simplex_idx = tsearchn( model.cellShapeModel.positions, ...
            model.cellShapeModel.tessellation, point );
    end
    
    points(i,:) = point;
    
    param.position = point;
        savedir = [scriptpath '_img' num2str(i)];
    if ~exist(savedir, 'dir')
        mkdir(savedir)
    end
    cd(savedir);
    
    param.targetDirectory = [scriptname filesep 'img' num2str(i)];
    
    imgs{i} = model2img( {model}, param );
end

answer = true;