function demo3Dimg2microtubule_model()
% demo3Dimg2microtubule_model
%
% Trains a generative model of microtubules

% Created: Ivan E. Cao-Berg & Gregory R. Johnson
%
% Copyright (C) 2014-2016 Murphy Lab
% Lane Center for Computational Biology
% School of Computer Science
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DO NOT MODIFY THIS BLOCK
current_path = which(mfilename);
[current_path, filename, extension] = fileparts( current_path );
cd(current_path);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

pattern = 'Tub';
imgdir = '../../../images/HeLa/3D/raw';
options.protein.class = 'microtubule';
options.protein.name = 'Tub';
options.nucleus.name = 'Tub';
options.cell.model = 'Tub';
options.faster = false;

dimensionality = '3D';
dna = [imgdir filesep 'Tub*cell*ch0*.tif'] ;
cell = [imgdir filesep 'Tub*cell*ch1*.tif'];
protein = [imgdir filesep 'Tub*cell*ch2*.tif'];
mask = [imgdir filesep 'Tub*cell*mask*.tif'];

% generic model options
% ---------------------
options.model.name = 'microtubule_growth';
options.model.id = num2str(now);
options.model.filename = [ lower(pattern) '.xml' ];

% nuclear shape model options
% ---------------------------
options.nucleus.class = 'nuclear_membrane';
options.nucleus.type = 'cylindrical_surface';
options.nucleus.id = num2str(now);

% cell shape model options
% ------------------------
options.cell.class = 'cell_membrane';
options.cell.type = 'ratio';
options.cell.id = num2str(now);

% protein shape model options
% ---------------------------
options.protein.class = 'network';
options.protein.type = 'microtubule_growth';
options.protein.id = num2str(now);

% other options
% -------------
options.verbose = true;

options.debug = true;
%options.train.flag = 'microtubule';
options.model.resolution = [0.049, 0.049, 0.2000];
options.downsampling = [4,4,1];
options.saveIntermediateResults = false;
options.model.microtubule.searchparams.n = [50:100:500];
options.model.microtubule.searchparams.mulen = [10:10:50];
options.model.microtubule.searchparams.colli_min_number = [0.97, 1 ];
options.protein.cytonuclearflag = 'cyto';
options.debug = true;
options.verbose = true;

dna_paths = dir(dna);
dna_paths = sort_nat({dna_paths.name});

prot_paths = dir(protein);
prot_paths = sort_nat({prot_paths.name});

cell_paths = dir(cell);
cell_paths = sort_nat({cell_paths.name});

mask_paths = dir(mask);
mask_paths = sort_nat({mask_paths.name});

for i = 1:length(dna_paths)
    cell_imgs{i} = @() seg_hela([imgdir filesep cell_paths{i}], [imgdir filesep mask_paths{i}]);
    dna_imgs{i} = @() seg_hela([imgdir filesep dna_paths{i}], [imgdir filesep mask_paths{i}]);
    prot_imgs{i} = [imgdir filesep prot_paths{i}];
end

if ~exist([pwd filesep 'tub.mat'], 'file')
    answer = img2slml( dimensionality, dna_imgs, cell_imgs, prot_imgs, options );
else
    answer = true;
end

