help demo3D12;
 
demopath = which('demo3D12');
fileseps = regexp(demopath, filesep);
demodir = demopath(1:fileseps(end));
cd(demodir)


TRAIN = true;
SYNTHESIS = false;
POSTPROCESSING = false;
 
%Mit
option = 3;
patterns = {'LAM','Mit','Nuc','TfR'};
model_filenames = {'./lam.mat', './mit.mat', './nuc.mat', './tfr.mat'};
downsampling_scale = 1;
 
pattern = patterns{option};
model_filename = model_filenames{option};
 



if TRAIN
    %run demo and make profile
    profile on
 
    param.downsampling = [ downsampling_scale, downsampling_scale, 1];
    param.proteinUpsampleZ = 5;
    param.use_preprocessed_images = true;
    param.train.flag = 'all';
 
    demo3D12( option, false, param );
    profile off
    movefile( model_filename, './model.mat' );
    profsave( profile('info'), 'profile' );
    zip( 'profile.zip', 'profile' )
    rmdir( 'profile', 's' );
end
 
if SYNTHESIS
    %try to synthesize images from model
    try
     state = rng(3);
    catch
     state = RandStream.create('mt19937ar','seed', 11);
     RandStream.setDefaultStream(state);
    end
 
    outputDirectory = pwd;
    param = [];
    param.targetDirectory = [ outputDirectory ];
    param.prefix = 'synthesizedImages';
    param.numberOfSynthesizedImages = 5;
    param.compression = 'lzw';
    param.microscope = 'none';
    param.synthesis = 'all';
    param.verbose = true;
    param.debug = true;
 
    slml2img( {'./model.mat'}, param );
end
 
if POSTPROCESSING
    input_images_directory = [ pwd filesep pattern ];
    output_images_directory = [ pwd filesep 'temp' filesep 'raw' ];
    answer = ...
        raw_images_gallery_wrapper( ...
            input_images_directory, output_images_directory );
 
    input_images_directory = [ pwd filesep 'intermediate_results' ];
    output_images_directory = [ pwd filesep 'temp' filesep 'intermediate' ];
    answer = ...
        intermediate_results_image_gallery_wrapper( ...
            input_images_directory, output_images_directory );
 
    input_images_directory = [ pwd filesep 'temp' filesep 'preprocessing' ];
    output_images_directory =  [ pwd filesep 'temp' filesep 'preprocessing' ];
    answer = ...
        preprocessed_images_gallery_wrapper( ...
            input_images_directory, output_images_directory );
 
    input_images_directory = [ pwd filesep 'synthesizedImages' ];
    output_images_directory = [ pwd filesep 'temp' filesep 'synthetic' ];
    synthesized_images_gallery_wrapper( ...
        input_images_directory, output_images_directory );
 
    input_images_directory = [ pwd filesep 'temp' filesep 'cell_shape_eigen' ]
    output_images_directory = [ pwd filesep 'temp' filesep 'cellcodes' ];
    cellcodes_images_gallery_wrapper( ...
        input_images_directory, output_images_directory );
end