% Yanyu Liang
%
% Copyright (C) 2013-2016 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef TestModel2Framework < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_cell_array_model( testCase )
            disp('test001: Should return empty lists if models is a cell array.')
            model = {};
            param = [];
            [nucimgs, cellimgs, outres] = model2framework(model, param);
            testCase.verifyEmpty( nucimgs );
            testCase.verifyEmpty( cellimgs );
            testCase.verifyEmpty( outres );
            temp = [ pwd filesep 'temp' ];
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_empty_model( testCase )
            disp('test002: Should return empty lists if model is empty')
            model = [];
            param = [];
            [nucimgs, cellimgs, outres] = model2framework(model, param);
            testCase.verifyEmpty( nucimgs );
            testCase.verifyEmpty( cellimgs );
            testCase.verifyEmpty( outres );
            temp = [ pwd filesep 'temp' ];
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_empty_param( testCase )
            disp('test003: Should continue if param is empty.')
            load('/models/2D/endosome.mat');
            param = [];
            models = { model };
            [nucimgs, cellimgs, outres] = model2framework( models, param );
            testCase.verifyNotEmpty( nucimgs );
            testCase.verifyNotEmpty( cellimgs );
            testCase.verifyNotEmpty( outres );
            
            temp = [ pwd filesep 'temp' ];
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_no_nuclear_shape_model( testCase )
            disp('test004: Should not continue (return empty lists) if model does not contain nuclearShapeModel')
            load('/models/2D/endosome.mat');
            model = rmfield(model, 'nuclearShapeModel');
            param.synthesis = 'framework';
            [nucimgs, cellimgs, outres] = model2framework(model, param);
            testCase.verifyEmpty( nucimgs );
            testCase.verifyEmpty( cellimgs );
            testCase.verifyEmpty( outres );
            
            temp = [ pwd filesep 'temp' ];
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_no_cell_shape_model( testCase )
            disp('test003: Should not continue if model does not contrain cellShapeModel')
            load('/models/2D/endosome.mat');
            model = rmfield(model, 'cellShapeModel');
            param.synthesis = 'framework';
            [nucimgs, cellimgs, outres] = model2framework(model, param);
            testCase.verifyEmpty( nucimgs );
            testCase.verifyEmpty( cellimgs );
            testCase.verifyEmpty( outres );
            
            temp = [ pwd filesep 'temp' ];
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
    end
end

