% Yanyu Liang
%
% Copyright (C) 2013-2016 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef TestModel2Instance < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_empty_model( testCase )
            disp('test001: If empty model is passed in, return empty lists.')
            model = [];
            param.synthesis = 'all';
            [object, outres] = model2instance(model, param);
            testCase.verifyEmpty( object );
            testCase.verifyEmpty( outres );
        end
        
        function test_non_struct_param( testCase )
            disp('test002: If param is not a struct, continue with default.')
            load('/models/2D/endosome.mat');
            param = 1;
            [object, outres] = model2instance(model, param);
            testCase.verifyEmpty( object );
            testCase.verifyEmpty( outres );
        end
        
        function test_list_model( testCase )
            disp('test003: If model is a list, should use the first model and continue')
            load('/models/2D/endosome.mat');
            param.synthesis = 'all';
            models = [model, model];
            [object, outres] = model2instance(models, param);
            testCase.verifyEmpty( object );
            testCase.verifyEmpty( outres );
        end
        
        function test_non_struct_model( testCase )
            disp('test004: If model is not a struct, return empty list')
            load('/models/2D/endosome.mat');
            model = 1;
            param.synthesis = 'all';
            [object, outres] = model2instance(model, param);
            testCase.verifyEmpty( object );
            testCase.verifyEmpty( outres );
        end
    end
end