% Ivan E. Cao-Berg
%
% Copyright (C) 2016 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef Test_2D_HeLa_model_training < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_training_nuclear_model( testCase )
            pattern = 'nuc';
            directory = [ '../../images/HeLa/2D/Nuc' ];
            
            param = [];
            param = ml_initparam( param, ...
                struct( 'verbose', false ) );
            param = ml_initparam( param, ...
                struct( 'debug', false ) );
            param = ml_initparam( param, ...
                struct( 'display', false ) );
            
            if exist( './model.mat', 'file' )
                delete( './model.mat' );
            end
            
            if exist( './param' )
                rmdir( './param', 's' );
            end
            
            dna = [ directory filesep 'orgdna' filesep '*.tif' ];
            cellm = [ directory filesep 'orgcell' filesep '*.tif' ];
            protein = [ directory filesep 'orgprot' filesep '*.tif' ];
            
            %main difference between this demo and demo2D01
            param.masks = [ directory filesep 'crop' filesep '*.tif' ];
            
            param.model.filename = 'model.xml';
            param.model.resolution = [ 0.49, 0.49 ];
            
            param.model.name = 'demo2D01';
            param.model.id = 'demo2D01';
            
            param.train.flag = 'nucleus';
            
            param.threshmeth_dna = 'rc';
            
            answer = img2slml( '2D', dna, cellm, protein, param );
            
            testCase.verifyTrue( logical(answer) );
            testCase.verifyTrue( logical(exist( 'model.mat', 'file' )) );
            testCase.verifyTrue( logical(exist( 'param', 'dir' )) );
            
            pattern = './param/param*/param*.mat';
            testCase.verifyEqual( 5, length(dir(pattern) ));
            
            load( './model.mat' );
            testCase.verifyTrue( isfield(model, 'nuclearShapeModel') );
            testCase.verifyTrue( ~isfield(model, 'cellShapeModel') );
            testCase.verifyTrue( ~isfield(model, 'proteinModel') );
            
            if exist( './model.mat', 'file' )
                delete( './model.mat' );
            end
            
            if exist( './param', 'dir' )
                rmdir( './param', 's' );
            end
        end
        
        function test_training_framework_model( testCase )
            pattern = 'nuc';
            directory = [ '../../images/HeLa/2D/Nuc' ];
            
            param = [];
            param = ml_initparam( param, ...
                struct( 'verbose', false ) );
            param = ml_initparam( param, ...
                struct( 'debug', false ) );
            param = ml_initparam( param, ...
                struct( 'display', false ) );
            
            if exist( './model.mat', 'file' )
                delete( 'model.mat' );
            end
            
            if exist( './param', 'dir' )
                rmdir( './param', 's' );
            end
            
            dna = [ directory filesep 'orgdna' filesep '*.tif' ];
            cellm = [ directory filesep 'orgcell' filesep '*.tif' ];
            protein = [ directory filesep 'orgprot' filesep '*.tif' ];
            
            %main difference between this demo and demo2D01
            param.masks = [ directory filesep 'crop' filesep '*.tif' ];
            
            param.model.filename = 'model.xml';
            param.model.resolution = [ 0.49, 0.49 ];
            
            param.model.name = 'demo2D01';
            param.model.id = 'demo2D01';
            
            param.train.flag = 'framework';
            
            param.threshmeth_dna = 'rc';
            
            answer = img2slml( '2D', dna, cellm, protein, param );
            
            testCase.verifyTrue( logical(answer) );
            testCase.verifyTrue( logical(exist( 'model.mat', 'file' )) );
            testCase.verifyTrue( logical(exist( 'param', 'dir' )) );
            
            pattern = './param/param*';
            testCase.verifyEqual( 5, length(dir(pattern) ));
            
            load( './model.mat' );
            testCase.verifyTrue( isfield(model, 'nuclearShapeModel') );
            testCase.verifyTrue( ~isfield(model, 'cellShapeModel') );
            testCase.verifyTrue( ~isfield(model, 'proteinModel') );
            
            if exist( './model.mat', 'file' )
                delete( './model.mat' );
            end
            
            if exist( './param' )
                rmdir( './param', 's' );
            end
        end
        
        function teardownOnce( testCase )
            folder = './intermediate_results/';
            if exist( folder )
                rmdir( folder, 's' );
            end
            
            folder = './param/';
            if exist( folder )
                rmdir( folder, 's' );
            end
            
            filename = './model.mat';
            if exist( filename )
                delete( filename );
            end
        end
    end
end

