% Yanyu Liang
%
% Copyright (C) 2013-16 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef TestImg2Model < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_not_specified_dimentionality( testCase )
            disp('test001: Should return empty model if no specified dimensionality')
            dimensionality = '';
            dnaPath = '/images/HeLa/3D/raw/LAMP2/*';
            cellPath = '/images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '/images/HeLa/3D/raw/LAMP2/*';
            param.tran.flag = 'all';
            model = img2model(dimensionality, dnaPath, cellPath, proteinPath, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEqualTo(0) | IsEmpty  );  
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_not_specified_dna_path_2D( testCase )
            disp('test002: Should return empty model if no specified dna path (2D)')
            dimensionality = '2D';
            dnaPath = '';
            cellPath = '/images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '/images/HeLa/3D/raw/LAMP2/*';
            param.tran.flag = 'all';
            model = img2model(dimensionality, dnaPath, cellPath, proteinPath, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEqualTo(0) | IsEmpty  );  
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_not_specified_dna_path_3D( testCase )
            disp('test003: Should return empty model if no specified 3D DNA images path')
            dimensionality = '3D';
            dnaPath = '';
            cellPath = '/images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '/images/HeLa/3D/raw/LAMP2/*';
            param.tran.flag = 'all';
            model = img2model(dimensionality, dnaPath, cellPath, proteinPath, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEqualTo(0) | IsEmpty  );  
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_empty_param( testCase )
            disp('test004: Should not continue if param is empty. Resolution has no default value.')
            dimensionality = '2D';
            dnaPath = '/images/HeLa/3D/raw/LAMP2/*';
            cellPath = '/images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '/images/HeLa/3D/raw/LAMP2/*';
            param = [];
            model = img2model(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyEmpty( model );  
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_empty_protein_path_in_training_framework( testCase )
            disp('test005: Should continue if training framework and protein path is empty')
            dimensionality = '3D';
            dnaPath = '/images/HeLa/3D/raw/LAMP2/*';
            cellPath = '/images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '';
            param.train.flag = 'framework';
            model = img2model(dimensionality, dnaPath, cellPath, proteinPath, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, ~IsEmpty | ~IsEqualTo(0) );  
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function test_non_string_cell_path( testCase )
            disp('test006: Should return false if cell path is  not a string')
            dimensionality = '2D';
            dnaPath = '/images/HeLa/3D/raw/LAMP2/*';
            cellPath = 2;
            proteinPath = '/images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            model = img2model(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( model ); %%check if the verification is correct!
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
        
        function teardownOnce( testCase )
            temp = './temp/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
    end
end

