% Yanyu Liang
%
% Copyright (C) 2013-2016 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef TestImg2Slml < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_empty_path_2d( testCase )
            disp('test001: Should return false if the paths are empty (2D)')
            dimensionality = '2d';
            dnaPath = '';
            cellPath = '';
            proteinPath = '';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_empty_path_3d( testCase )
            disp('test002: Should return false if the paths are empty (3D)')
            dimensionality = '3d';
            dnaPath = '';
            cellPath = '';
            proteinPath = '';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_no_dimensionality( testCase )
            disp('test003: Should return false if there is no dimentionality')
            dimensionality = '';
            dnaPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_no_supported_dimensionality( testCase )
            disp('test004: Should return false if there is no supported dimentionality')
            dimensionality = '4d';
            dnaPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_empty_param( testCase )
            disp('test005: Should not continue if param is empty because resolution has no default value')
            dimensionality = '2d';
            dnaPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param = struct([]);
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_empty_dna_path( testCase )
            disp('test006: Should not continue if DNA images path is empty')
            dimensionality = '2d';
            dnaPath = '';
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml( dimensionality, dnaPath, cellPath, proteinPath, param );
            testCase.verifyFalse( answer );
        end
        
        function test_non_string_dna_path( testCase )
            disp('test008: Should not continue if DNA images path is not a string')
            dimensionality = '2d';
            dnaPath = 1;
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_non_string_cell_images_path( testCase )
            disp('test009: Should not continue if cell images path is not a string')
            dimensionality = '2d';
            dnaPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            cellPath = 2;
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_non_string_protein_path( testCase )
            disp('test010: Should not continue if protein path is not a string')
            dimensionality = '2d';
            dnaPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = 3;
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_non_existing_dna_path( testCase )
            disp('test011: Should not continue if DNA images path does not exist')
            dimensionality = '2d';
            dnaPath = 'non/existing/path';
            cellPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
        
        function test_non_existing_cell_path( testCase )
            disp('test012: Should not continue if cell images path does not exist')
            dimensionality = '2d';
            cellPath = 'non/existing/path';
            dnaPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            proteinPath = '../../../images/HeLa/3D/raw/LAMP2/*';
            param.train.flag = 'all';
            answer = img2slml(dimensionality, dnaPath, cellPath, proteinPath, param);
            testCase.verifyFalse( answer );
        end
    end
end

