% Yanyu Liang
%
% Copyright (C) 2013-2016 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef TestMlTraingenmodel < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_non_list_protimages( testCase )
            disp('test001: Should return an empty model if input protimages is not a list')
            protimages = '';
            dnaimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            cellimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            masks = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            param.train.flag = 'all';
            model = ml_traingenmodel(protimages, dnaimages, cellimages, masks, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEmpty | IsEqualTo(0) );
        end
        
        function test_non_list_dnaimages( testCase )
            disp('test002: Should return an empty model if input dnaimages is not a list')
            protimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            dnaimages = '';
            cellimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            masks = {};
            param.train.flag = 'all';
            model = ml_traingenmodel(protimages, dnaimages, cellimages, masks, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEmpty | IsEqualTo(0) );
        end
        
        function test_non_list_cellimages( testCase )
            disp('test003: Should return an empty model if input cellimages is not a list')
            protimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            dnaimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            cellimages = '';
            masks = {};
            param.train.flag = 'all';
            model = ml_traingenmodel(protimages, dnaimages, cellimages, masks, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEmpty | IsEqualTo(0) );
        end
        
        function test_empty_all_inputs( testCase )
            disp('test004: Should return an empty model if all input lists are empty')
            protimages = {};
            dnaimages = {};
            cellimages = {};
            masks = {};
            param.train.flag = 'all';
            model = ml_traingenmodel(protimages, dnaimages, cellimages, masks, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEmpty | IsEqualTo(0) );
        end
        
        function test_empty_param( testCase )
            disp('test005: Should continue if param is empty')
            protimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            dnaimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            cellimages = {'/images/HeLa/3D/raw/LAMP2/cell1_mask_t1.tif'};
            masks = {};
            param = [];
            model = ml_traingenmodel(protimages, dnaimages, cellimages, masks, param);
            
            import matlab.unittest.constraints.IsEmpty
            import matlab.unittest.constraints.IsEqualTo
            testCase.verifyThat( model, IsEmpty | IsEqualTo(0) );
        end
    end
end
