% Yanyu Liang
%
% Copyright (C) 2013-2016 Murphy Lab
% Carnegie Mellon University
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published
% by the Free Software Foundation; either version 2 of the License,
% or (at your option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% You should have received a copy of the GNU General Public License
% along with this program; if not, write to the Free Software
% Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
% 02110-1301, USA.
%
% For additional information visit http://murphylab.web.cmu.edu or
% send email to murphy@cmu.edu

classdef TestTrainNucShapeModel < matlab.unittest.TestCase
    properties
    end
    
    methods (Test)
        function test_non_cell_array_nucfeats( testCase )
            disp('test001: Should return an empty model nucfeats is not a cell array')
            mkdir('test');
            nucfeats = 'notcellarray';
            param = [];
            savepath = 'test';
            model = train_nuc_shape_model(nucfeats, savepath, param);
            
            testCase.verifyEmpty( model );
            
            temp = './test/';
            if exist(temp)
                rmdir( temp, 's' );
            end
        end
        
        function test_empty_nucfeats( testCase )
            disp('test002: Should return an empty model nucfeats is an empty cell array')
            mkdir('test');
            nucfeats = {};
            param = [];
            savepath = 'test';
            model = train_nuc_shape_model(nucfeats, savepath, param);
            
            testCase.verifyEmpty( model );
            
            temp = './test/';
            if exist(temp)
                rmdir( temp, 's' );
            end
        end
        
        function test_non_struct_param( testCase )
            disp('test003: Should continue with default if param is not a struct')
            mkdir('test');
            nucfeats = {};
            param = 1;
            savepath = '';
            model = train_nuc_shape_model(nucfeats, savepath, param);
            
            testCase.verifyEmpty( model );
            temp = './test/';
            if exist(temp)
                rmdir( temp, 's' );
            end
            
        end
        
        function test_not_exist_savepath( testCase )
            disp('test004: If savepath does not exist')
            nucfeats = {};
            param = [];
            savepath = 'this/file/path/does/not/exist';
            model = train_nuc_shape_model(nucfeats, savepath, param);
            
            testCase.verifyEmpty( model );
            temp = './test/';
            if exist(temp)
                rmdir( temp, 's' );
            end
            
        end
%         
%         function test_training_nuclear_model( testCase )
%             pattern = 'nuc';
%             directory = [ '../../images/HeLa/2D/Nuc' ];
%             
%             param = [];
%             param = ml_initparam( param, ...
%                 struct( 'verbose', false ) );
%             param = ml_initparam( param, ...
%                 struct( 'debug', false ) );
%             param = ml_initparam( param, ...
%                 struct( 'display', false ) );
%             
%             if exist( './model.mat', 'file' )
%                 delete( './model.mat' );
%             end
%             
%             if exist( './param' )
%                 rmdir( './param', 's' );
%             end
%             
%             dna = [ directory filesep 'orgdna' filesep '*.tif' ];
%             cellm = [ directory filesep 'orgcell' filesep '*.tif' ];
%             protein = [ directory filesep 'orgprot' filesep '*.tif' ];
%             
%             %main difference between this demo and demo2D01
%             param.masks = [ directory filesep 'crop' filesep '*.tif' ];
%             
%             param.model.filename = 'model.xml';
%             param.model.resolution = [ 0.49, 0.49 ];
%             
%             param.model.name = 'demo2D01';
%             param.model.id = 'demo2D01';
%             
%             param.train.flag = 'nucleus';
%             
%             param.threshmeth_dna = 'rc';
%             
%             answer = img2slml( '2D', dna, cellm, protein, param );
%             
%             testCase.verifyTrue( logical(answer) );
%             testCase.verifyTrue( logical(exist( 'model.mat', 'file' )) );
%             testCase.verifyTrue( logical(exist( 'param', 'dir' )) );
%             
%             pattern = './param/param*.mat';
%             testCase.verifyEqual( 5, length(dir(pattern) ));
%             
%             load( './model.mat' );
%             testCase.verifyTrue( isfield(model, 'nuclearShapeModel') );
%             testCase.verifyTrue( ~isfield(model, 'cellShapeModel') );
%             testCase.verifyTrue( ~isfield(model, 'proteinModel') );
%             
%             if exist( './model.mat', 'file' )
%                 delete( './model.mat' );
%             end
%             
%             if exist( './param', 'dir' )
%                 rmdir( './param', 's' );
%             end
%         end
        
        function teardownOnce( testCase )
            temp = './test/';
            
            if exist( temp )
                rmdir( temp, 's' );
            end
        end
    end
end
